@@ -10,7 +10,7 @@ from mitosheet.saved_analyses.step_upgraders.utils_column_header_to_column_id im
     replace_headers_with_id
 
 
-def upgrade_change_column_dtype_1_to_2(step: Dict[str, Any], later_steps: List[Dict[str, Any]]):
+def upgrade_change_column_dtype_1_to_2(step: Dict[str, Any], later_steps: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
     """
     Moves to using column id instead of column header.
 
