@@ -34,7 +34,7 @@ class DataframeDuplicateStepPerformer(StepPerformer):
         return 'dataframe_duplicate_edit'
 
     @classmethod
-    def saturate(cls, prev_state: State, params) -> Dict[str, str]:
+    def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
         return params
 
     @classmethod
