@@ -97,9 +97,8 @@ def test_overwrites_step_valid():
         }
     })
 
-    steps_manager = mito.mito_widget.steps_manager
-    assert len(steps_manager.steps) == 3
-    assert steps_manager.dfs[0].equals(pd.DataFrame(data={'A': [1, 2, 3], 'C': [0, 0, 0]}))
+    assert len(mito.steps) == 3
+    assert mito.dfs[0].equals(pd.DataFrame(data={'A': [1, 2, 3], 'C': [0, 0, 0]}))
 
 
 def test_failed_overwrite_rolls_back_to_previous_state():
@@ -118,8 +117,7 @@ def test_failed_overwrite_rolls_back_to_previous_state():
         }
     })
 
-    steps_manager = mito.mito_widget.steps_manager
-    assert len(steps_manager.steps) == 2
-    assert steps_manager.dfs[0].equals(pd.DataFrame(data={'A': [1, 2, 3], 'B': [0, 0, 0]}))
+    assert len(mito.steps) == 2
+    assert mito.dfs[0].equals(pd.DataFrame(data={'A': [1, 2, 3], 'B': [0, 0, 0]}))
 
 
