@@ -1,8 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
+# Copyright (c) Mito.
 
 """
 Contains some types that are useful in the Mitosheet package. 
@@ -12,9 +11,8 @@ explicit and clear, and make sure to test the types in our
 continous integration
 """
 
-from typing import TYPE_CHECKING, List, Union, Tuple, Any
+from typing import List, Union, Tuple
 
-GraphID = str
 ColumnID = str
 
 # A column header is either a primative type
@@ -23,12 +21,4 @@ MultiLevelColumnHeader = Union[Tuple[PrimativeColumnHeader, ...], List[Primative
 # To a tuple of primative types (TODO: does this nest further?).
 ColumnHeader = Union[PrimativeColumnHeader, MultiLevelColumnHeader]
 
-# To resolve circular dependencies, we create a StepsManagerType here
-if TYPE_CHECKING:
-    from mitosheet.steps_manager import StepsManager
-    StepsManagerType = StepsManager
-else:
-    StepsManagerType = Any
-
-
 
