@@ -8,15 +8,24 @@
 Rolls back/forward to a specific step, by index
 """
 
+from typing import TYPE_CHECKING, Any
+
+
+if TYPE_CHECKING:
+    from mitosheet.steps_manager import StepsManager
+else:
+    StepsManager = Any
+
+
 CHECKOUT_STEP_BY_IDX_UPDATE_EVENT = 'checkout_step_by_idx_update'
 CHECKOUT_STEP_BY_IDX_UPDATE_PARAMS = [
     'step_idx'
 ]
 
 def execute_checkout_step_by_idx_update(
-        steps_manager,
-        step_idx
-    ):
+        steps_manager: StepsManager,
+        step_idx: int
+    ) -> None:
     """
     Checks out a specific step by index
     """
