@@ -6,11 +6,11 @@ from mitosheet.user.db import (
 )
 from mitosheet.user.utils import (
     is_running_test, is_on_kuberentes_mito, is_local_deployment,
-    should_upgrade_mitosheet
+    should_upgrade_mitosheet, is_pro
 )
 from mitosheet.user.schemas import (
     UJ_INTENDED_BEHAVIOR, UJ_CLOSED_FEEDBACK, UJ_MITOSHEET_LAST_FIVE_USAGES,
     UJ_USER_JSON_VERSION, UJ_STATIC_USER_ID, UJ_USER_SALT, UJ_USER_EMAIL, 
     UJ_RECEIVED_TOURS, UJ_FEEDBACKS, UJ_FEEDBACKS_V2, UJ_MITOSHEET_CURRENT_VERSION, 
     UJ_MITOSHEET_LAST_UPGRADED_DATE, UJ_MITOSHEET_LAST_FIFTY_USAGES, UJ_MITOSHEET_PRO
-)
\ No newline at end of file
+)
